# meticulous

[![Azure Status](https://dev.azure.com/timgates/timgates/_apis/build/status/timgates42.meticulous?branchName=master)](https://dev.azure.com/timgates/timgates/_build/latest?definitionId=6&branchName=master)
[![Travis Status](https://travis-ci.org/timgates42/meticulous.svg?branch=master)](https://travis-ci.org/timgates42/meticulous)
[![Appveyor Status](https://ci.appveyor.com/api/projects/status/arf9j0ri5v0kg368?svg=true)](https://ci.appveyor.com/project/timgates42/meticulous)
[![PyPI version](https://img.shields.io/pypi/v/meticulous.svg)](https://pypi.org/project/meticulous)
[![Python Versions](https://img.shields.io/pypi/pyversions/meticulous.svg)](https://pypi.org/project/meticulous)
[![PyPI downloads per month](https://img.shields.io/pypi/dm/meticulous.svg)](https://pypi.org/project/meticulous)
[![Documentation Status](https://readthedocs.org/projects/meticulous/badge/?version=latest)](https://meticulous.readthedocs.io/en/latest/?badge=latest)
[![Coverage Status](https://coveralls.io/repos/github/timgates42/meticulous/badge.svg)](https://coveralls.io/github/timgates42/meticulous/)
[![Black](https://camo.githubusercontent.com/28a51fe3a2c05048d8ca8ecd039d6b1619037326/68747470733a2f2f696d672e736869656c64732e696f2f62616467652f636f64652532307374796c652d626c61636b2d3030303030302e737667)](https://github.com/psf/black)

Automate process of forking and running pyspelling on a repository to locate typos.

More details can be found in the
[Online Documentation.](https://meticulous.readthedocs.io/en/latest/)

# Installation

You can install meticulous for
[Python](https://www.python.org/) via
[pip](https://pypi.org/project/pip/)
from [PyPI](https://pypi.org/).

```
$ pip install meticulous
```





## Download from PyPI.org

https://pypi.org/project/meticulous/



# Contributing

Contributions are very welcome, consider using the
[file an issue](https://github.com/timgates42/meticulous/issues)
to discuss the work before beginning, but if you already have a Pull Request
ready then this is no problem, please submit it and it will be very gratefully
considered. The [Contribution Guidelines](CONTRIBUTING.md)
outlines the meticulous commitment to ensuring all
contributions receive appropriate recognition.

# License


Distributed under the terms of the [GPLv3](https://opensource.org/licenses/GPL-3.0)
license, "meticulous" is free and open source software


# Issues

If you encounter any problems, please
[file an issue](https://github.com/timgates42/meticulous/issues)
along with a detailed description.

# Additional Documentation:

* [Online Documentation](https://meticulous.readthedocs.io/en/latest/)
* [News](NEWS.rst).
* [Template Updates](COOKIECUTTER_UPDATES.md).
* [Code of Conduct](CODE_OF_CONDUCT.md).
* [Contribution Guidelines](CONTRIBUTING.md).
